# -*- coding: utf-8 -*-

import os, sys
from setuptools import find_packages, setup
from babel.messages import frontend as babel
from distutils.cmd import Command
from trac.util.dist import get_l10n_js_cmdclass


commands = {'compile_catalog': babel.compile_catalog,
            'extract_messages': babel.extract_messages,
            'init_catalog': babel.init_catalog,
            'update_catalog': babel.update_catalog}

commands.update(get_l10n_js_cmdclass())

try:
    from epydoc import cli
except ImportError:
    print 'epydoc not installed, skipping API documentation target.'
else:
    class build_apidoc(Command):
        description = 'Builds the api documentation'
        user_options = []
        boolean_options = []

        def initialize_options(self):
            pass

        def finalize_options(self):
            pass

        def run(self):
            epydoc_conf = os.path.join('docs', 'epydoc.conf')
            old_argv = sys.argv[1:]
            sys.argv[1:] = [
                '--check',
                '-v',
                '--config=%s' % epydoc_conf,
                '--no-private']
            try:
                cli.cli()
            except:
                pass
            finally:
                sys.argv[1:] = old_argv
    commands['build_apidoc'] = build_apidoc

setup(
    name='TracRendezVous',
    version='0.3',
    packages=find_packages(),
    install_requires = {
        #'PIL': ['Imaging>=1.1.6']
    },
    zip_safe=False,
    entry_points = """
        [trac.plugins]
        tracrendezvous.location.web_ui = tracrendezvous.location.web_ui
        tracrendezvous.event.web_ui = tracrendezvous.event.web_ui
        tracrendezvous.rendezvous.web_ui = tracrendezvous.rendezvous.web_ui
    """,
    cmdclass = commands,
    message_extractors = {'tracrendezvous': [
        ('**.py', 'python', None),
        ('**/templates/**.html', 'genshi', None),
        ('**/templates/**.txt',  'genshi', {
            'template_class': 'genshi.template:TextTemplate'
        })
      ],
    },
    package_data={
        '' : ['templates/*'],
        'tracrendezvous': [
            'htdocs/css/*.css',
            'htdocs/script/*.js',
            'htdocs/images/*',
            'locale/*/LC_MESSAGES/*.mo', 'htdocs/tracrendezvous/*.js'
            ],
        'tracrendezvous.location': ['htdocs/css/*.css','htdocs/script/*.js','htdocs/images/*'],
        'tracrendezvous.rendezvous': ['*.ttf','htdocs/css/*.css','htdocs/script/*.js','htdocs/images/*'],
        'tracrendezvous.event': [ 'htdocs/css/*.css', 'htdocs/script/*.js', 'htdocs/images/*']},

    author = "Stefan Kögl",
    author_email = "skoegl@online.de",
    description = "a plugin for meeting dates syndication and event calendar with ical export",
    license = "GPL",
    keywords = "rendezvous, dates, teaming, syndication, calendar",
    url = "http://trac.ctdo.de/dev/",   # project home page, if any
    #requires=["Imaging (>=1.1.6)"],
    test_suite = 'tracrendezvous.test.suite'
)
